@@ -4,7 +4,7 @@ __all__ = ["connect", "Connection", "Cursor"]
 
 import sqlite3
 from collections.abc import Callable, Sequence
-from functools import partial, wraps
+from functools import partial, update_wrapper
 from logging import Logger, getLogger
 from types import TracebackType
 from typing import Any
@@ -46,18 +46,21 @@ class Connection:
             exception_handled = self._exception_handler(exc_type, exc_val, exc_tb, self._log)
         return exception_handled
 
-    @wraps(sqlite3.Connection.close)
     async def close(self):
         return await to_thread.run_sync(self._real_connection.close, limiter=self._limiter)
 
-    @wraps(sqlite3.Connection.commit)
+    update_wrapper(close, sqlite3.Connection.close)
+
     async def commit(self):
         return await to_thread.run_sync(self._real_connection.commit, limiter=self._limiter)
 
-    @wraps(sqlite3.Connection.rollback)
+    update_wrapper(commit, sqlite3.Connection.commit)
+
     async def rollback(self):
         return await to_thread.run_sync(self._real_connection.rollback, limiter=self._limiter)
 
+    update_wrapper(rollback, sqlite3.Connection.rollback)
+
     async def cursor(self, factory: Callable[[sqlite3.Connection], sqlite3.Cursor] = sqlite3.Cursor) -> Cursor:
         real_cursor = await to_thread.run_sync(self._real_connection.cursor, factory, limiter=self._limiter)
         return Cursor(real_cursor, self._limiter)
@@ -80,37 +83,44 @@ class Cursor:
     def arraysize(self) -> int:
         return self._real_cursor.arraysize
 
-    @wraps(sqlite3.Cursor.close)
     async def close(self) -> None:
         await to_thread.run_sync(self._real_cursor.close, limiter=self._limiter)
 
-    @wraps(sqlite3.Cursor.execute)
+    update_wrapper(close, sqlite3.Cursor.close)
+
     async def execute(self, sql: str, parameters: Sequence[Any] = (), /) -> Cursor:
         real_cursor = await to_thread.run_sync(self._real_cursor.execute, sql, parameters, limiter=self._limiter)
         return Cursor(real_cursor, self._limiter)
 
-    @wraps(sqlite3.Cursor.executemany)
+    update_wrapper(execute, sqlite3.Cursor.execute)
+
     async def executemany(self, sql: str, parameters: Sequence[Any], /) -> Cursor:
         real_cursor = await to_thread.run_sync(self._real_cursor.executemany, sql, parameters, limiter=self._limiter)
         return Cursor(real_cursor, self._limiter)
 
-    @wraps(sqlite3.Cursor.executescript)
+    update_wrapper(executemany, sqlite3.Cursor.executemany)
+
     async def executescript(self, sql_script: str, /) -> Cursor:
         real_cursor = await to_thread.run_sync(self._real_cursor.executescript, sql_script, limiter=self._limiter)
         return Cursor(real_cursor, self._limiter)
 
-    @wraps(sqlite3.Cursor.fetchone)
+    update_wrapper(executescript, sqlite3.Cursor.executescript)
+
     async def fetchone(self) -> tuple[Any, ...] | None:
         return await to_thread.run_sync(self._real_cursor.fetchone, limiter=self._limiter)
 
-    @wraps(sqlite3.Cursor.fetchmany)
+    update_wrapper(fetchone, sqlite3.Cursor.fetchone)
+
     async def fetchmany(self, size: int) -> list[tuple[Any, ...]]:
         return await to_thread.run_sync(self._real_cursor.fetchmany, size, limiter=self._limiter)
 
-    @wraps(sqlite3.Cursor.fetchall)
+    update_wrapper(fetchmany, sqlite3.Cursor.fetchmany)
+
     async def fetchall(self) -> list[tuple[Any, ...]]:
         return await to_thread.run_sync(self._real_cursor.fetchall, limiter=self._limiter)
 
+    update_wrapper(fetchall, sqlite3.Cursor.fetchall)
+
 
 async def connect(
     database: str,
